@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: js-jquery
-version: 1.12.1
-id: js-jquery-1.12.1-cb4fee5dc2f301f8b48d430c321cbb84
-key: jsjqu_4aj7QpZxzjoAJpTzPPSteP
+version: 1.12.2
+id: js-jquery-1.12.2-60fc2af6d883a5909b2d58515558f582
+key: jsjqu_Ffevaho3mcvBCDgBCFhunA
 license: MIT
 copyright: Neil Mitchell 2014-2016
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -21,10 +21,10 @@ exposed-modules:
     Language.Javascript.JQuery
 hidden-modules: Paths_js_jquery
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/js-jquery-1.12.1
-hs-libraries: HSjs-jquery-1.12.1-4aj7QpZxzjoAJpTzPPSteP
+import-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/js-jquery-1.12.2
+hs-libraries: HSjs-jquery-1.12.2-Ffevaho3mcvBCDgBCFhunA
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
 haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
